@@ -7,7 +7,8 @@ import pandas as pd
 import requests
 from numpy import nan
 
-from bblocks.config import PATHS
+from bblocks.config import BBPaths
+
 
 URL: str = "https://www.imf.org/external/Pubs/ft/dsa/dsalist.pdf"
 
@@ -60,25 +61,26 @@ def __clean_dsa(df: pd.DataFrame) -> pd.DataFrame:
     )
 
 
-def get_dsa(
-    update=False, local_path: str = f"{PATHS.imported_data}/dsa_list.pdf"
-) -> pd.DataFrame:
-    """Extract DSA data from the
+def get_dsa(update=False, local_path: str = None) -> pd.DataFrame:
+    """Extract DSA _data from the
 
-    Extract the most recent Debt Sustainability Assessment (DSA) data
+    Extract the most recent Debt Sustainability Assessment (DSA) _data
     for PRGT-Eligible Countries from the IMF website.
     URL = https://www.imf.org/external/Pubs/ft/dsa/DSAlist.pdf
 
     Args:
         local_path: where the downloaded PDF will be stored
-        update (bool): if True, updates the data from the IMF website. Otherwise
-            it loads the data from the local file. If a local file does not exist,
-            the data will be extracted from the website.
+        update (bool): if True, updates the _data from the IMF website. Otherwise
+            it loads the _data from the local file. If a local file does not exist,
+            the _data will be extracted from the website.
 
     Returns:
         pandas dataframe with country, latest publication date, and risk of debt distress
     """
 
+    if local_path is None:
+        local_path = f"{BBPaths.imported_data}/dsa_list.pdf"
+
     if not os.path.exists(local_path) or update:
         __download_dsa_pdf(URL, local_path)
 
